{% extends "base.html" %}

{% block content %}
This is Foo
<hr>
<table>
<tr><td>FOO_EMAIL</td><td>{{ config.FOO_EMAIL }}</td></tr>
<tr><td>FOO_NUM</td><td>{{ config.FOO_NUM }}</td></tr>
</table>


{% endblock %}