{% extends "base.html" %}

{% block content %}
This is Bar

<hr>
<a href="{% url 'app_bar_index' website %}">Index</a>
<a href="{% url 'app_bar_page1' website %}">Page 1</a>
<a href="{% url 'app_bar_page2' website %}">Page 2</a>
<a href="{% url 'app_bar_page3' website %}">Page 3</a>
<hr>
<table>
<tr><td>BAR_EMAIL</td><td>{{ config.BAR_EMAIL }}</td></tr>
<tr><td>BAR_NUM</td><td>{{ config.BAR_NUM }}</td></tr>
<tr><td>BAR_CHAR</td><td>{{ config.BAR_CHAR }}</td></tr>
</table>

{% block template_content %}{% endblock %}

{% endblock %}