{% extends "base.html" %}

{% block content %}


<h2>Usage</h2>
<ol>
 <li><a href="{% url 'admin:app_list' 'site_config' %}">View the Admin interface</a>
 	<ol>
 		<li><a href="{% url 'admin:site_config_website_changelist' %}">Add a Website</a></li>
 		<li><a href="{% url 'admin:site_config_application_changelist' %}">Add an Application</a></li>
 		<li><a href="{% url 'admin:site_config_websiteapplication_changelist' %}">Add a Website Application</a></li>
 	</ol>
 </li>
 <li>View the sample applications.  Making changes to the Webiste Application settings will update the settings
 	displayed here.  Only website applications that have been fully enabled will be accessable.
 	<ol>
	 	{% for website in websites %} 		
 		<li> {{ website.name }} ({{ website.short_name }})
		 	<ol>
		 	  <li><a href="{% url 'app_foo_index' website.short_name %}">View Example App Foo index.</a></li>
		      <li><a href="{% url 'app_bar_index' website.short_name %}">View Example App Bar index.</a></li>
		 	</ol> 
 	    </li>
	 	{% endfor %}
 	</ol>
 </li>
</ol>
{% endblock %}